Reference - Template Time Date Variables

# custom_datetime[^source]
[^source]: For further details see [this Joplin forum page](https://discourse.joplinapp.org/t/reference-template-time-date-variables/24672). Note also that these variables are intended for use with templates, which are explained at [this site](https://github.com/joplin/plugin-templates).

## <a id="variables-2"></a>[](#variables-2)Variables

The below should be enclosed in `custom_datetime` tags in the template

`{{#custom_datetime}}`*variables*`{{/custom_datetime}}`

| Value | Output | Note |
| --- | --- | --- |
| `d` | 5   | Day of the week (0-6 = Sun-Sat) |
| `dd` | Fr  | Day of the week (name abbreviated 2 characters) |
| `ddd` | Fri | Day of the week (name abbreviated 3 characters) |
| `dddd` | Friday | Day of the week (name full) |
| `e` | 4   | Day of the week (Locale Aware)* (0-6) |
| `E` | 5   | Day of the week (ISO) (1-7 = Mon-Sun) |
| `D` | 25  | Date |
| `Do` | 25th | Date (with suffix) |
| `DD` | 25  | Date (always 2 digits) |
| `DDD` | 84  | Day of the year |
| `DDDo` | 84th | Day of the year (with suffix) |
| `DDDD` | 084 | Day of the year (always 3 digits) |
| `w` | 12  | Week of the year |
| `wo` | 12th | Week of the year (with suffix) |
| `ww` | 12  | Week of the year (always 2 digits) |
| `W` | 12  | Week of the year (ISO) |
| `Wo` | 12th | Week of the year (ISO) (with suffix) |
| `WW` | 12  | Week of the year (ISO) (always 2 digits) |
| `M` | 3   | Month (numeric) |
| `Mo` | 3rd | Month (numeric) (with suffix) |
| `MM` | 03  | Month (numeric always 2 digits) |
| `MMM` | Mar | Month (name abbreviated) |
| `MMMM` | March | Month (name full) |
| `Y` | 2022 | Year (ISO) |
| `YY` | 22  | Year (abbreviated) |
| `YYYY` | 2022 | Year (full) |
| `YYYYYY` | +002022 | Year (Expanded) |
| `y` | 2022 | Era Year |
| `gggg` | 2022 | Week Year for "Week Dates" (e.g. 2022-W12-4) |
| `GGGG` | 2022 | Week Year (ISO) for "[Week Dates](https://en.wikipedia.org/wiki/ISO_8601#Week_dates)" (e.g. 2022-W12-5) |
| `Q` | 1   | Quarter |
| `Qo` | 1st | Quarter (with suffix) |
| `h` | 5   | Hour (12 hour clock) |
| `hh` | 05  | Hour (12 hour clock always 2 digits) |
| `H` | 17  | Hour (0-23) (24 hour clock) |
| `HH` | 17  | Hour (0-23) (24 hour clock always 2 digits) |
| `m` | 55  | Minutes |
| `mm` | 55  | Minutes (always 2 digits) |
| `s` | 17  | Seconds |
| `ss` | 17  | Seconds (always 2 digits) |
| `S` | 6   | Fractional Seconds - tenths |
| `SS` | 62  | Fractional Seconds - hundredths |
| `SSS` | 622 | Fractional Seconds - thousandths |
| `a` | pm  | am / pm indicator |
| `A` | PM  | AM / PM indicator |
| `Z` | +00:00 | Timezone Offset (with colon separator) |
| `ZZ` | +0000 | Timezone Offset |
| `X` | 1648230917 | Unix Timestamp |
| `x` | 1648230917622 | Unix Millisecond Timestamp |
| `N` | AD  | Era (abbreviated) |
| `NNNN` | Anno Domini | Era (full) |
| `LT` | 17:55 | Localised format - time* |
| `LTS` | 17:55:17 | Localised format - time (with seconds)* |
| `l` | 25/3/2022 | Localised format - date (no leading zeros)* |
| `L` | 25/03/2022 | Localised format - date* |
| `ll` | 25 Mar 2022 | Localised format - date (short month)* |
| `LL` | 25 March 2022 | Localised format - date (long month)* |
| `lll` | 25 Mar 2022 17:55 | Localised format - date / time (short month)* |
| `LLL` | 25 March 2022 17:55 | Localised format - date / time (long month)* |
| `llll` | Fri, 25 Mar 2022 17:55 | Localised format - day / date / time (short)* |
| `LLLL` | Friday, 25 March 2022 17:55 | Localised format - day / date / time (long)* |

\* *The output format displayed will vary with region for each user*

# <a id="joplin-3"></a>[](#joplin-3)Joplin

## <a id="variables-4"></a>[](#variables-4)Variables

The below should be enclosed in double curly brackets in the template *not* custom_datetime tags.

`{{`*variable*`}}`

| Value | Output | Note |
| --- | --- | --- |
| `date` | 2022-03-25 | Date |
| `time` | 13:07 | Time |
| `datetime` | 2022-03-25 13:07 | Date and time |
| `bows` | 2022-03-20 | Date of the beginning of the week (Sunday) |
| `bowm` | 2022-03-21 | Date of the beginning of the week (Monday) |

*The above display the date / time format **as it is set in Joplin***

# <a id="examples-5"></a>[](#examples-5)Examples

### <a id="friday-25th-march-2022-107-pm-6"></a>[](#friday-25th-march-2022-107-pm-6)Friday 25th March 2022 1:07 PM

`dddd Do MMMM YYYY h:mm A`

* * *

### <a id="fri-25-mar-2022-13073504-7"></a>[](#fri-25-mar-2022-13073504-7)Fri 25 Mar 2022 13:07:35.04

`ddd DD MMM YYYY HH:mm:ss.SS`

* * *

### <a id="h-2022-03-25t1307350000-8"></a>[](#h-2022-03-25t1307350000-8)2022-03-25T13:07:35+00:00

`Y-MM-DDTHH:mm:ssZ`

id: 441e56d1cbdf43ae909e76121b9b865b
parent_id: 9909e4c9862c4cb7a110173fe722e9b5
created_time: 2022-03-29T00:26:46.358Z
updated_time: 2022-03-29T00:30:59.993Z
is_conflict: 0
latitude: 0.00000000
longitude: 0.00000000
altitude: 0.0000
author: 
source_url: https://discourse.joplinapp.org/t/reference-template-time-date-variables/24672
is_todo: 0
todo_due: 0
todo_completed: 0
source: joplin-desktop
source_application: net.cozic.joplin-desktop
application_data: 
order: 1648513606358
user_created_time: 2022-03-29T00:26:46.358Z
user_updated_time: 2022-03-29T00:30:59.993Z
encryption_cipher_text: 
encryption_applied: 0
markup_language: 1
is_shared: 0
share_id: 
conflict_original_id: 
master_key_id: 
type_: 1